@@ -17,7 +17,8 @@ def get_cli_pii_data(args):
     pii_gen.insert_data_in_mongo(args.conn)
     print("*************" * 5)
     print("Data Inserted successfully")
-    pii_gen.get_data_in_json_file()
+  s = pii_gen.get_data_in_json_file()
+  print(str(s), "status of data insert")
   return pii_gen.get_data_in_dict()
 
 def main():
